import './index.css';
import nameGenerator from './name-generator';
import isDef from './is-def';


// Store/retrieve the name in/from a cookie.
const cookies = document.cookie.split(';');

let wsname = cookies.find(function(c) {
  if (c.match(/wsname/) !== null) return true;
  return false;
});
if (isDef(wsname)) {
  wsname = wsname.split('=')[1];
} else {
  wsname = nameGenerator();
  document.cookie = 'wsname=' + encodeURIComponent(wsname);
}

// Set the name in the header
document.querySelector('header>p').textContent = decodeURIComponent(wsname);

// Create a WebSocket connection to the server//TODO
const ws = new WebSocket('ws://' + window.location.host+ "/socket");

//TODO
// We get notified once connected to the server
ws.onopen = (event) => {
  console.log('Connecté!');
};

//Gestion des couleurs
var violet = '#871de0';
var rose = '#eb159d';
var rouge = '#c92626';
var orange = '#db551b';
var jaune = '#ddc41e';
var vert = '#76b80f';
var bleu = '#1974b4';
var noir = '#000';
var blanc = '#fff';
var gris = '#e6e6e6';

//Gestion de la couleur actuelle
var coulAct = noir;
//Gestion de la couleur des traits
var listCol = [];
//Gestion de la taille actuelle
var lineWidth = 5;
//Gestion de la taille des traits
var listWid = [];

//Création des boutons couleurs
document.getElementById('couleurs').setAttribute('align', 'center');
document.getElementById('violet').onclick = function(e) {coulAct = violet; changeCol(violet);}
document.getElementById('rose').onclick = function(e) {coulAct = rose; changeCol(rose);}
document.getElementById('rouge').onclick = function(e) {coulAct = rouge; changeCol(rouge);}
document.getElementById('orange').onclick = function(e) {coulAct = orange; changeCol(orange);}
document.getElementById('jaune').onclick = function(e) {coulAct = jaune; changeCol(jaune);}
document.getElementById('vert').onclick = function(e) {coulAct = vert; changeCol(vert);}
document.getElementById('bleu').onclick = function(e) {coulAct = bleu; changeCol(bleu);}
document.getElementById('noir').onclick = function(e) {coulAct = noir; changeCol(noir);}
document.getElementById('blanc').onclick = function(e) {coulAct = blanc; changeCol(gris);}

//Création des boutons  tailles
document.getElementById('tailles').setAttribute('align', 'center');
document.getElementById('un').onclick = function(e) {lineWidth = 1; select(this); }
document.getElementById('cinq').onclick = function(e) {lineWidth = 5; select(this); }
document.getElementById('dix').onclick = function(e) {lineWidth = 10; select(this); }
document.getElementById('quinze').onclick = function(e) {lineWidth = 15; select(this); }
document.getElementById('vingt').onclick = function(e) {lineWidth = 20; select(this); }

//Création du bouton clear
document.getElementById('clear').onclick = function(e) {ws.send('/C/');clear();}

//Création de la zone de canvas
var canvasDiv = document.getElementById('canvas');
var canvas = document.createElement('canvas');
canvas.setAttribute('width', 800);
canvas.setAttribute('height', 500);
canvas.setAttribute('id', 'dessin');
canvasDiv.setAttribute('align', 'center');
canvasDiv.appendChild(canvas);
var context = canvas.getContext('2d');
context.lineWidth = lineWidth;


//Permet d'afficher la taille utilisé
function select(e) {
  var actif = document.getElementsByClassName('actif');
  if(actif[0] !== undefined) {
    actif[0].removeAttribute('class');
  }
  e.setAttribute('class', 'actif');
}

/***********************************************************************************************/
/***********************************************************************************************/
/***********************************************************************************************/
/***********************************************************************************************/
/***********************************************************************************************/

//Paramètres de dessin
var clickX = [];
var clickY = [];
var clickDrag = [];
var paint;


function addClick(x, y, dragging) {
  clickX.push(x);
  clickY.push(y);
  clickDrag.push(dragging);
  listCol.push(coulAct);
  listWid.push(lineWidth);
}

function addClick2(x, y, coul, width, dragging) {
  clickX.push(x);
  clickY.push(y);
  clickDrag.push(dragging);
  listCol.push(coul);
  listWid.push(width);
}

//Nettoye le canvas
function clear() {
  var i;
  for(i = 0; i < listCol.length; i++) {
    listCol[i] = blanc;
  }
  context.clearRect(0, 0, context.canvas.width, context.canvas.height);
  coulAct = noir;
  changeCol(coulAct);
}

//Rajout du dessin
function redraw(event){
  
  context.lineJoin = "round";

  for(var i=0; i < clickX.length; i++) {    
    context.beginPath();
    if(clickDrag[i] && i){
      context.moveTo(clickX[i-1], clickY[i-1]);
    }
    else{
      context.moveTo(clickX[i]-1, clickY[i]);
    }

    context.lineTo(clickX[i], clickY[i]);
    context.closePath();
    context.strokeStyle = listCol[i];
    context.lineWidth = listWid[i];
    context.stroke();
  }


}

/***********************************************************************************/

var tabX = [], tabY = [];

//Gestion d'appui sur le bouton de la souris
canvas.onmousedown = function(e) {
  var mousX = e.pageX - this.offsetLeft;
  var mousY = e.pageY - this.offsetTop;

  tabX.push(mousX);
  tabY.push(mousY);

  paint = true;
  addClick(mousX, mousY);

  redraw(e);
}



//Gestion du mouvement de la souris
canvas.onmousemove = function(e) {
  if(paint) {
    var mousX = e.pageX - this.offsetLeft;
    var mousY = e.pageY - this.offsetTop;

    tabX.push(mousX);
    tabY.push(mousY);


  //  if(tabX.length > 200) {
  //    envoi(e);
  //  }

    addClick(mousX, mousY);
    redraw(e);

  }
}

function envoi(e) {
  ws.send('/D' +'/' + tabX + '/' + tabY + '/'+ e + '/' + coulAct + '/' + lineWidth);//TODO
  tabX = [];
  tabY = [];
}

//Réception du message
ws.onmessage = (event) => {
  var data = event.data
  var tracer = data.split('/');

  if(tracer[1] === 'D') {
    var i;
    var mousX = tracer[2].split(',');
    var mousY = tracer[3].split(',');

    //coulAct = tracer[5];
    //lineWidth = tracer[6];

    for(i = 0; i < tracer[2].length; i++) {
      addClick2(mousX[i],mousY[i], tracer[5], tracer[6]);
      redraw(tracer[4]);
    } 

    
    
  }

  if(tracer[1] === 'C') {
    clear();
  }
};

//Gestion de non appui sur le bouton de la souris
canvas.onmouseup = function(e) {
  paint = false;
  envoi(e);
}

//Gestion de la sortie de la fenêtre
canvas.onmouseleave = function(e) {
  //paint = false
}


/***********************************************************************************/

//La couleur de fond correspond à la couleur que l'on utilise
function changeCol(couleur) {document.getElementById('body').setAttribute('style', 'background-color: '+couleur);}

/***********************************************************************************************/


